==> core-1.11.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Reference.java <==
package software.amazon.awscdk.core;

/**
 * An intrinsic Token that represents a reference to a construct.
 * 
 * References are recorded.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.1 (build f4a0dbe)", date = "2019-10-02T18:14:53.816Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Reference")
public abstract class Reference extends software.amazon.awscdk.core.Intrinsic {

    protected Reference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Reference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param value This parameter is required.
     * @param target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Reference(final java.lang.Object value, final software.amazon.awscdk.core.IConstruct target) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { value, java.util.Objects.requireNonNull(target, "target is required") }));
    }

    /**
     * Check whether this is actually a Reference.
     * 
     * @param x This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isReference(final java.lang.Object x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Reference.class, "isReference", java.lang.Boolean.class, new Object[] { x });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.IConstruct getTarget() {
        return this.jsiiGet("target", software.amazon.awscdk.core.IConstruct.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.core.Reference {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * 
         * If this returns an empty array the stack will not be attached.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(this.jsiiGet("creationStack", java.util.List.class));
        }

        /**
         * Produce the Token's value at resolution time.
         * 
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public java.lang.Object resolve(final software.amazon.awscdk.core.IResolveContext context) {
            return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }

        /**
         * Return a string representation of this resolvable object.
         * 
         * Returns a reversible string representation.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public java.lang.String toString() {
            return this.jsiiCall("toString", java.lang.String.class);
        }
    }
}

==> core-1.12.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Reference.java <==
package software.amazon.awscdk.core;

/**
 * An intrinsic Token that represents a reference to a construct.
 * 
 * References are recorded.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.18.0 (build f29d29c)", date = "2019-10-07T15:30:25.509Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Reference")
public abstract class Reference extends software.amazon.awscdk.core.Intrinsic {

    protected Reference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Reference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param value This parameter is required.
     * @param target This parameter is required.
     * @param displayName
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Reference(final java.lang.Object value, final software.amazon.awscdk.core.IConstruct target, final java.lang.String displayName) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { value, java.util.Objects.requireNonNull(target, "target is required"), displayName }));
    }

    /**
     * @param value This parameter is required.
     * @param target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Reference(final java.lang.Object value, final software.amazon.awscdk.core.IConstruct target) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { value, java.util.Objects.requireNonNull(target, "target is required") }));
    }

    /**
     * Check whether this is actually a Reference.
     * 
     * @param x This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isReference(final java.lang.Object x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Reference.class, "isReference", java.lang.Boolean.class, new Object[] { x });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDisplayName() {
        return this.jsiiGet("displayName", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.IConstruct getTarget() {
        return this.jsiiGet("target", software.amazon.awscdk.core.IConstruct.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.core.Reference {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * 
         * If this returns an empty array the stack will not be attached.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(this.jsiiGet("creationStack", java.util.List.class));
        }

        /**
         * Produce the Token's value at resolution time.
         * 
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public java.lang.Object resolve(final software.amazon.awscdk.core.IResolveContext context) {
            return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }

        /**
         * Return a string representation of this resolvable object.
         * 
         * Returns a reversible string representation.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public java.lang.String toString() {
            return this.jsiiCall("toString", java.lang.String.class);
        }
    }
}
